@@ -1,22 +1,22 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-#    magma - Readout and create Magma lists. 
+# MAGnet MAnifest Management - Readout and create lists of magnets in yaml format. 
 # 
-#    Copyright © 2008 Arne Babenhauserheide
+# Copyright © 2008 Arne Babenhauserheide
 # 
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>
 
 
 """MAGnet MAnifest Management - Readout and create lists of magnets in yaml format. 
@@ -142,17 +142,16 @@ Also dump yaml data via magma.dump()
 
 Plans: 
     - Also pass metadata and include that alongside the file list. 
-    - Also check if passed data is magma data (has magma header). 
     - Add Alt-locs (depends on the network used). Maybe GNet-Alt-Loc for Gnutella. Gets parsed to magnet xs automatically. 
    
 Ideas: 
     - If given both magma list and files, the magma list gets extended by the files. 
     - Joining and seperating magma lists. 
-    - Passing several input lists to join with the main list. 
+    - Passing several additional input lists to join with the main list. 
     - Passing the data of files along with magma metadata to create the list. 
     - Passing the indizes of files to automatically slice the list. maybe even with the syntax sliced_magma = magma[a:b]
-    - Readout metadata from files, for example using the taglib or such. 
-    - If a dir gets passed, add all files within that dir. Alsa a parameter to ask, if it should be done rekursively. 
+    - Readout metadata from files, for example using the taglib, pyPdf or such. 
+    - If a dir gets passed, add all files within that dir. Alsa a parameter to ask, if it should be done recursively. 
     - If hashing files takes very long (for example seen with clock.tick()), give more output. 
     - Add more commandline switches (verbose, help, ... - see the babtools_gentoo script)
 
@@ -165,12 +164,18 @@ __copyright__ = 'Copyright (C) 2008 Arne Babenhauserheide'
 __date__ = '2008-05-09'
 __licence__ = 'GPL-3 or later'
 __program__ = 'MAGnet MAnifest Management'
-__version__ = '0.2.5'
+__version__ = '0.2.7'
 
 # The dependencies of the _init__ only. 
 __depends__ = ''
 
 def parse_dependencies(init_depends):
+    """Aggregate the dependencies from ann submodules.
+    
+    @param init_depends: The dependencies of the __init__ file. 
+    @type init_depends: String 
+    @return: A string with dependencies, seperated by ', '. 
+    """
     # aggregate dependencies from all submodules. 
     dep_list = [init_depends]
     from create_simple_magma_list import __depends__ 
@@ -201,8 +206,9 @@ from magma_list import Magma
 def load(yaml_data):
     """Parse a Magma list and produce the corresponding Python object.
     
-    @param data: Data read from a yaml file
-    @type data: String
+    @param yaml_data: Data read from a yaml file
+    @type yaml_data: String
+    @return: A Magma Object. 
     """
     return Magma(yaml_data=yaml_data)
     
@@ -210,7 +216,9 @@ def dump(magma):
     """Return the string representation of the Magma file.
     
     @param magma: A Magma object.
-    @type magma: magma.Magma"""
+    @type magma: magma.Magma
+    @return: A String represenation of the Magma file (in yaml format). 
+    """
     return magma.__str__()
     
     
@@ -219,7 +227,10 @@ def dump(magma):
 #### Self-Test ####
 
 def _test():
-    """Do all doctests"""
+    """Do all doctests
+    
+    @return: None
+    """
     # Get the testmod function from the doctest module. 
     from doctest import testmod
     # And call it. 
