@@ -1,22 +1,22 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-#    magma - Readout and create Magma lists. 
+# MAGnet MAnifest Management - Readout and create lists of magnets in yaml format. 
 # 
-#    Copyright © 2008 Arne Babenhauserheide
+# Copyright © 2008 Arne Babenhauserheide
 # 
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>
 
 
 """
@@ -51,7 +51,16 @@ from yaml import dump, load
 from os.path import dirname
 
 def strip_dirname(path):
-    """Strip everything but the name of the file."""
+    """Strip everything but the name of the file.
+    
+    @param path: A path to a file. 
+    @type path: String
+    @return: The name of teh file, stripped of anything before it. 
+        
+        Example: /home/blah/blubb.magma becomes
+        
+        blubb.magma
+       """
     # We just as many characters from the beginning of the string as the dirname is long. 
     if len(dirname(path)) > 0: 
         filename = path[len(dirname(path)) + 1:]
@@ -60,7 +69,13 @@ def strip_dirname(path):
     return filename
 
 class Magma: 
+    """A Simple Magma object created from a list of input file paths."""
     def __init__(self, inputfilenames):
+        """A Simple Magma object created from a list of input file paths.
+        
+        @param inputfilenames: The paths to the files to hash.
+        @type inputfilenames: List
+        """
         #: The names of the files. 
         self.filenames = inputfilenames
         #: Sha1 values to the files. The sha1 gets computed for each one here, so this isn't ambigous. 
@@ -74,7 +89,9 @@ class Magma:
         self.magma = self.magma()
         
     def data(self):
-        """Calculate the Python data of the Magma file."""
+        """Get the Python data of the Magma file (a dict).
+        
+        @return: The data of the Magma file as Python dict. """
         magma = {}
         list_of_magnets = []
         for i in self.filenames: 
@@ -87,10 +104,16 @@ class Magma:
         return magma
         
     def magma(self): 
-        """Dump the yaml version of the file with a MAGMA header."""
+        """Dump the yaml representation of the file with a MAGMA header as string.
+        
+        @return: A string representation of the Magma file (in yaml format). """
         return MAGMA_0_4_HEADER + "\n" + dump(self.data, default_flow_style=False)
 
 def _test(): 
+    """Do all doctests
+    
+    @return: None
+    """
     from doctest import testmod
     testmod()
 
